==> nusolve_0.7.6.orig.tar.gz: nusolve-0.7.6/doc/html/classSgChannelSetup.js <==
var classSgChannelSetup =
[
    [ "BackEndType", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8ea", [
      [ "BET_UNDEF", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa17ed0704a86885fbb9dc4d5e6e6e8d6a", null ],
      [ "BET_NONE", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa3c004b67d438327618bd10a268091a65", null ],
      [ "BET_DBBC", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa458a1ff2773083b1d14dd83692b45416", null ],
      [ "BET_DBBC3", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa8f94d21bf7e7c5463a4512a201915996", null ],
      [ "BET_RDBE", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa43692f16cf31e45e4f41db41c408c89e", null ],
      [ "BET_OTHER", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa222a4fe6aa0ef1b04543496c3f196965", null ]
    ] ],
    [ "HwType", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63", [
      [ "HT_UNDEF", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63a544e59ebd30c83c6fd84997682a09fe8", null ],
      [ "HT_VC", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63ae95a2a5f5b76897173c0bfb46ee13f8e", null ],
      [ "HT_BBC", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63a2113f15240515f7e748e8cc4a21c4e7e", null ],
      [ "HT_NN", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63ad0af290d8f9646902521a9695f4a943d", null ],
      [ "HT_VGOS", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63a036436b018d6eda171ab2253a2db9bed", null ]
    ] ],
    [ "SgChannelSetup", "classSgChannelSetup.html#a5538ac4acc38fe6de045040ddc27322e", null ],
    [ "~SgChannelSetup", "classSgChannelSetup.html#a298a39f1b8d1a79bb93262acfcefc815", null ],
    [ "bbcBandwidthByIdx", "classSgChannelSetup.html#a639cb4947f068bc592448f67136bf4c6", null ],
    [ "bbcFreqByIdx", "classSgChannelSetup.html#a844a650cf6fae14dff039ba8f1d52e5a", null ],
    [ "calcSkyFreq", "classSgChannelSetup.html#aa582d653a7bfb1c05e0b14d650c5bd08", null ],
    [ "className", "classSgChannelSetup.html#aaf63df2441c0aebab84399668a282f1d", null ],
    [ "getBackEndType", "classSgChannelSetup.html#af156644271c895826df30c11a1c41a2b", null ],
    [ "getHwType", "classSgChannelSetup.html#a65acf965c6ae3de2e6b18c8d3f075040", null ],
    [ "ifBandwidthBySensorKey", "classSgChannelSetup.html#a35df38db8645087af801b35253da2b2c", null ],
    [ "ifFreqByIdx", "classSgChannelSetup.html#ae8e250794480e2aabdf0cf124a99b2f0", null ],
    [ "ifFreqBySensorKey", "classSgChannelSetup.html#a2476095d163d924ab95a26d5debe58a7", null ],
    [ "ifIdBySensorKey", "classSgChannelSetup.html#a762a553cebe2009575a8f2c14d459404", null ],
    [ "ifIdxById", "classSgChannelSetup.html#a2aab575aed665acaa08d84a59c6c6a29", null ],
    [ "ifPolarizationById", "classSgChannelSetup.html#ae1cf402117f4e00845c90fbe458963c1", null ],
    [ "ifSideBandById", "classSgChannelSetup.html#a2663488548e1f6da0f3f1744af01a9ce", null ],
    [ "isOk", "classSgChannelSetup.html#a02c3c53442727efff983c81acf66b836", null ],
    [ "loFreqById", "classSgChannelSetup.html#a86559bf2672df5032f58a871592d347d", null ],
    [ "loFreqBySensorKey", "classSgChannelSetup.html#acf29d8e0a616bc0dadc858c4c49b4bf3", null ],
    [ "loIdByCid", "classSgChannelSetup.html#aad7a603b2c4d6f7e5c19ffb1bd30e524", null ],
    [ "loIdByIdx", "classSgChannelSetup.html#acba73ef402381b9b3129c924e6699d2b", null ],
    [ "loIdBySensorKey", "classSgChannelSetup.html#abf008dc8b70426c43405f04d9381e966", null ],
    [ "loPolarizationById", "classSgChannelSetup.html#a35ddc33405bd1ec8d73248608ec5c897", null ],
    [ "loPolarizationBySensorKey", "classSgChannelSetup.html#abcd04cd5ee5fde75a0b1d18f4312374d", null ],
    [ "loSideBandById", "classSgChannelSetup.html#a2fa831a472fc99384c8c3a0ccdae8089", null ],
    [ "loSideBandBySensorKey", "classSgChannelSetup.html#af81e5855917e962abd62c4b1ddc9b39c", null ],
    [ "origSensorIdById", "classSgChannelSetup.html#a2cfdca988f7b7be89832240306e2ceda", null ],
    [ "pcalIdByKey", "classSgChannelSetup.html#a9fa1a40ea319c18384f0f04be64990de", null ],
    [ "pcalPolarizationById", "classSgChannelSetup.html#a4146add8e7b9da5973211368347f7dde", null ],
    [ "selfCheck", "classSgChannelSetup.html#a7f925f985aa98c01f7756442f8ebbffc", null ],
    [ "setBackEndType", "classSgChannelSetup.html#a71f7a1fba9a3ba9a2f9aeede3305200c", null ],
    [ "setHwType", "classSgChannelSetup.html#afda635cac6608842165efcd114160b53", null ],
    [ "xpsIdByKey", "classSgChannelSetup.html#a84fc84deaa0b6e843206738304fbe7e2", null ],
    [ "backEndType_", "classSgChannelSetup.html#ad460194069101dc532bfb644af11e67c", null ],
    [ "bbcBandwidthByIdx_", "classSgChannelSetup.html#af5ca604e985bc00b1f8b80ae571e29fa", null ],
    [ "bbcFreqByIdx_", "classSgChannelSetup.html#ac16eb18e860e3cd4f80dc1b852840529", null ],
    [ "hwType_", "classSgChannelSetup.html#a3782d1f0ff3f07e4bc812b72e86cb06b", null ],
    [ "ifBandwidthBySensorKey_", "classSgChannelSetup.html#a423c5d48a264a4d5273c511150eeed73", null ],
    [ "ifFreqByIdx_", "classSgChannelSetup.html#a38b6e84392943a513740feadc8547022", null ],
    [ "ifFreqBySensorKey_", "classSgChannelSetup.html#aac4af8e727ecbc1dbf82e1d47a760153", null ],
    [ "ifIdBySensorKey_", "classSgChannelSetup.html#a8ceda21c770b8487701f36f94a40924a", null ],
    [ "ifIdxById_", "classSgChannelSetup.html#aa5624f03f5eadf895b25149c8dfb7725", null ],
    [ "ifPolarizationById_", "classSgChannelSetup.html#a78169fa7947ab454f0dae244d3253bcc", null ],
    [ "ifSideBandById_", "classSgChannelSetup.html#af63982f99572f70609df5806d372c03c", null ],
    [ "isOk_", "classSgChannelSetup.html#a9579e339023f57f6e1da1647d64d0fda", null ],
    [ "loFreqById_", "classSgChannelSetup.html#aca6d5782356b81f11c74340ef2a347d2", null ],
    [ "loFreqBySensorKey_", "classSgChannelSetup.html#ad8bbc2f6b74097c95648d91f24d174e3", null ],
    [ "loIdByCid_", "classSgChannelSetup.html#a5814d9a2a5a82e9794f5db83a9620cd8", null ],
    [ "loIdByIdx_", "classSgChannelSetup.html#aaebeedd59acc7ee41b3e1f0eccea3d97", null ],
    [ "loIdBySensorKey_", "classSgChannelSetup.html#a446555a7dd63f5e6a7986358735e2165", null ],
    [ "loPolarizationById_", "classSgChannelSetup.html#a2ed7fb6aa303581fca4c48dc4f5876fa", null ],
    [ "loPolarizationBySensorKey_", "classSgChannelSetup.html#a62aaf5730d71d2538b10df39e14dfbff", null ],
    [ "loSideBandById_", "classSgChannelSetup.html#aacc385513d5b382980130219618f0a06", null ],
    [ "loSideBandBySensorKey_", "classSgChannelSetup.html#a639fa398fc1aca6f11e79ccf8553a4c9", null ],
    [ "origSensorIdById_", "classSgChannelSetup.html#a5bb0823360c0630b0e615eb39caa9208", null ],
    [ "pcalIdByKey_", "classSgChannelSetup.html#a0df624ee91feab241976047042495228", null ],
    [ "pcalPolarizationById_", "classSgChannelSetup.html#a01eb70911652bb1e5ce7fd9d498b9d52", null ],
    [ "xpsIdByKey_", "classSgChannelSetup.html#a58439f30e19fcbbd1c05ffa2dd890b41", null ]
];

==> nusolve-0.8.2.tar.gz: nusolve-0.8.2/doc/html/classSgChannelSetup.js <==
var classSgChannelSetup =
[
    [ "BackEndType", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8ea", [
      [ "BET_UNDEF", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa17ed0704a86885fbb9dc4d5e6e6e8d6a", null ],
      [ "BET_NONE", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa3c004b67d438327618bd10a268091a65", null ],
      [ "BET_DBBC", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa458a1ff2773083b1d14dd83692b45416", null ],
      [ "BET_DBBC3", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa8f94d21bf7e7c5463a4512a201915996", null ],
      [ "BET_RDBE", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa43692f16cf31e45e4f41db41c408c89e", null ],
      [ "BET_OTHER", "classSgChannelSetup.html#a7668983c6490230a2274506adfd3a8eaa222a4fe6aa0ef1b04543496c3f196965", null ]
    ] ],
    [ "HwType", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63", [
      [ "HT_UNDEF", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63a544e59ebd30c83c6fd84997682a09fe8", null ],
      [ "HT_VC", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63ae95a2a5f5b76897173c0bfb46ee13f8e", null ],
      [ "HT_BBC", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63a2113f15240515f7e748e8cc4a21c4e7e", null ],
      [ "HT_NN", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63ad0af290d8f9646902521a9695f4a943d", null ],
      [ "HT_VGOS", "classSgChannelSetup.html#a8a271b4ee4d0829ec9e34fd8d6e27c63a036436b018d6eda171ab2253a2db9bed", null ]
    ] ],
    [ "SgChannelSetup", "classSgChannelSetup.html#a5538ac4acc38fe6de045040ddc27322e", null ],
    [ "~SgChannelSetup", "classSgChannelSetup.html#a298a39f1b8d1a79bb93262acfcefc815", null ],
    [ "bbcBandwidthByIdx", "classSgChannelSetup.html#a639cb4947f068bc592448f67136bf4c6", null ],
    [ "bbcFreqByIdx", "classSgChannelSetup.html#a844a650cf6fae14dff039ba8f1d52e5a", null ],
    [ "calcSkyFreq", "classSgChannelSetup.html#aa582d653a7bfb1c05e0b14d650c5bd08", null ],
    [ "className", "classSgChannelSetup.html#aaf63df2441c0aebab84399668a282f1d", null ],
    [ "getBackEndType", "classSgChannelSetup.html#af156644271c895826df30c11a1c41a2b", null ],
    [ "getHwType", "classSgChannelSetup.html#a65acf965c6ae3de2e6b18c8d3f075040", null ],
    [ "ifBandwidthByTpSensorKey", "classSgChannelSetup.html#aa71a162f76eb4f14d0887cc131d105d6", null ],
    [ "ifFreqByIdx", "classSgChannelSetup.html#ae8e250794480e2aabdf0cf124a99b2f0", null ],
    [ "ifFreqByTpSensorKey", "classSgChannelSetup.html#a9443a83f41796008fe8674816e0a3a62", null ],
    [ "ifIdByTpSensorKey", "classSgChannelSetup.html#a4408d924feb1f7719be8e01006a409c4", null ],
    [ "ifIdxById", "classSgChannelSetup.html#a2aab575aed665acaa08d84a59c6c6a29", null ],
    [ "ifPolarizationById", "classSgChannelSetup.html#ae1cf402117f4e00845c90fbe458963c1", null ],
    [ "ifSideBandById", "classSgChannelSetup.html#a2663488548e1f6da0f3f1744af01a9ce", null ],
    [ "isOk", "classSgChannelSetup.html#a02c3c53442727efff983c81acf66b836", null ],
    [ "loFreqById", "classSgChannelSetup.html#a86559bf2672df5032f58a871592d347d", null ],
    [ "loFreqByTpSensorKey", "classSgChannelSetup.html#ad0d4d28fb9358427e139470c007baa4b", null ],
    [ "loIdByCid", "classSgChannelSetup.html#aad7a603b2c4d6f7e5c19ffb1bd30e524", null ],
    [ "loIdByIdx", "classSgChannelSetup.html#acba73ef402381b9b3129c924e6699d2b", null ],
    [ "loIdByTpSensorKey", "classSgChannelSetup.html#a383f57aa7df3ef3cfc4aadf8cd4803fd", null ],
    [ "loPcWidthById", "classSgChannelSetup.html#a9fc45e4f8312c76e4a633cba67fa7c59", null ],
    [ "loPolarizationById", "classSgChannelSetup.html#a35ddc33405bd1ec8d73248608ec5c897", null ],
    [ "loPolarizationByTpSensorKey", "classSgChannelSetup.html#a11c1c921f25d617f831c3e2a1eb4f00a", null ],
    [ "loSideBandById", "classSgChannelSetup.html#a2fa831a472fc99384c8c3a0ccdae8089", null ],
    [ "loSideBandByTpSensorKey", "classSgChannelSetup.html#afd8fb2a016b29eaa2357733693b9c264", null ],
    [ "origSensorIdById", "classSgChannelSetup.html#a2cfdca988f7b7be89832240306e2ceda", null ],
    [ "pcalIdByKey", "classSgChannelSetup.html#a9fa1a40ea319c18384f0f04be64990de", null ],
    [ "pcalLoFreqByKey", "classSgChannelSetup.html#a2594d0b3c6d0bcbf2697e376976df9de", null ],
    [ "pcalOffsetByKey", "classSgChannelSetup.html#a04801424417179801affed351815a8cb", null ],
    [ "pcalOffsetByLoId", "classSgChannelSetup.html#a6bfe5532ea62ac59a67ef926cdc1ef7a", null ],
    [ "pcalPolarizationByKey", "classSgChannelSetup.html#a6b56cc053a84047010bffa649f7214f4", null ],
    [ "pcalSideBandByKey", "classSgChannelSetup.html#ae9bd2528ecd51b268ebc0c2374c894df", null ],
    [ "pcalWidthByKey", "classSgChannelSetup.html#a2f11a25ee382515116577b4ffcd7e097", null ],
    [ "selfCheck", "classSgChannelSetup.html#a7f925f985aa98c01f7756442f8ebbffc", null ],
    [ "setBackEndType", "classSgChannelSetup.html#a71f7a1fba9a3ba9a2f9aeede3305200c", null ],
    [ "setHwType", "classSgChannelSetup.html#afda635cac6608842165efcd114160b53", null ],
    [ "xpsIdByKey", "classSgChannelSetup.html#a84fc84deaa0b6e843206738304fbe7e2", null ],
    [ "backEndType_", "classSgChannelSetup.html#ad460194069101dc532bfb644af11e67c", null ],
    [ "bbcBandwidthByIdx_", "classSgChannelSetup.html#af5ca604e985bc00b1f8b80ae571e29fa", null ],
    [ "bbcFreqByIdx_", "classSgChannelSetup.html#ac16eb18e860e3cd4f80dc1b852840529", null ],
    [ "hwType_", "classSgChannelSetup.html#a3782d1f0ff3f07e4bc812b72e86cb06b", null ],
    [ "ifBandwidthByTpSensorKey_", "classSgChannelSetup.html#ae9087fbcf3bc440283a6392745042709", null ],
    [ "ifFreqByIdx_", "classSgChannelSetup.html#a38b6e84392943a513740feadc8547022", null ],
    [ "ifFreqByTpSensorKey_", "classSgChannelSetup.html#a9efd2c8d8ab38e50c7e038e6767a5c21", null ],
    [ "ifIdByTpSensorKey_", "classSgChannelSetup.html#aeb3050315a8626faebfffa0117565e41", null ],
    [ "ifIdxById_", "classSgChannelSetup.html#aa5624f03f5eadf895b25149c8dfb7725", null ],
    [ "ifPolarizationById_", "classSgChannelSetup.html#a78169fa7947ab454f0dae244d3253bcc", null ],
    [ "ifSideBandById_", "classSgChannelSetup.html#af63982f99572f70609df5806d372c03c", null ],
    [ "isOk_", "classSgChannelSetup.html#a9579e339023f57f6e1da1647d64d0fda", null ],
    [ "loFreqById_", "classSgChannelSetup.html#aca6d5782356b81f11c74340ef2a347d2", null ],
    [ "loFreqByTpSensorKey_", "classSgChannelSetup.html#a54c2df29022b8ebc81132189109e16e7", null ],
    [ "loIdByCid_", "classSgChannelSetup.html#a5814d9a2a5a82e9794f5db83a9620cd8", null ],
    [ "loIdByIdx_", "classSgChannelSetup.html#aaebeedd59acc7ee41b3e1f0eccea3d97", null ],
    [ "loIdByTpSensorKey_", "classSgChannelSetup.html#a515824ef0d92b6eea0d2e57e80dc7421", null ],
    [ "loPcWidthById_", "classSgChannelSetup.html#a3f581cec47bd317d1db4c66e434e546b", null ],
    [ "loPolarizationById_", "classSgChannelSetup.html#a2ed7fb6aa303581fca4c48dc4f5876fa", null ],
    [ "loPolarizationByTpSensorKey_", "classSgChannelSetup.html#aec59fb6bbe034814588e5ddbf9957cea", null ],
    [ "loSideBandById_", "classSgChannelSetup.html#aacc385513d5b382980130219618f0a06", null ],
    [ "loSideBandByTpSensorKey_", "classSgChannelSetup.html#a611edbb67d04e69adcf29c85fb1f8788", null ],
    [ "origSensorIdById_", "classSgChannelSetup.html#a5bb0823360c0630b0e615eb39caa9208", null ],
    [ "pcalIdByKey_", "classSgChannelSetup.html#a0df624ee91feab241976047042495228", null ],
    [ "pcalLoFreqByKey_", "classSgChannelSetup.html#a6d725b3adb19ba771200ce669ee0ff87", null ],
    [ "pcalOffsetByKey_", "classSgChannelSetup.html#a7a091dec50920aefae011646341814f7", null ],
    [ "pcalOffsetByLoId_", "classSgChannelSetup.html#aadb19d8e022846a0d4ed382cd9c0eff2", null ],
    [ "pcalPolarizationByKey_", "classSgChannelSetup.html#af6770cda355c84708b9aaad4bb5eebb8", null ],
    [ "pcalSideBandByKey_", "classSgChannelSetup.html#a6c966d13c0f55e0987f9db756605ef57", null ],
    [ "pcalWidthByKey_", "classSgChannelSetup.html#a4c1d8c8891cabf6a73deccfc52debfbc", null ],
    [ "xpsIdByKey_", "classSgChannelSetup.html#a58439f30e19fcbbd1c05ffa2dd890b41", null ]
];
